---
name: Enhancement request
about: Request a new feature addition
title: ''
labels: enhancement
assignees: ''
---

### Type of the feature
<!-- What kind of feature would you like to be added? Put an `x` in all applicable boxes: -->
- [ ] New function in `trisicell.io`?
- [ ] New function in `trisicell.pl`?
- [ ] New function in `trisicell.pp`?
- [ ] New function in `trisicell.tl`?
- [ ] New function in `trisicell.ul`?
- [ ] New function in `trisicell.commands`?
- [ ] New function in `trisicell.datasets`?
- [ ] Change an existing functionality, such as default behavior?
- [ ] Other?

### Description
<!-- Describe the requested feature below: -->
...
